#!/bin/sh

echo "Hello in entrypoint"

usage() {
    printf "\n"
    printf "Usage: $(basename $0) -c -r -f path_to_repo -n cov_project_name -v cov_project_version -d snapshot_id \n"
    printf "\n"
    printf "\t-c\t for Coverity scanning and report generation\n"
    printf "\t-f\t Repository path to be scanned\n"
    printf "\t-r\t for only CVSS report generating\n"
    printf "\t-n\t Coverity project name\n"
    printf "\t-v\t Coverity project version\n"
    printf "\t-d\t Coverity Snapshot ID\n"
}


[ -z "$COV_URL" ] && fatal "COV_URL not set"
[ -z "$COV_USER" ] && fatal "COV_USER not set"
[ -z "$COVERITY_PASSPHRASE" ] && fatal "COVERITY_PASSPHRASE not set"

COV_SCAN_REPORT=0
REPO_TO_SCAN=""
ONLY_REPORT=0
COV_PRJ_NAME=""
COV_PRJ_VER=""
COV_SNAPSHOT_ID=""


while getopts "cf:rn:v:d:p:" flag; do
    case "${flag}" in
        c)
            COV_SCAN_REPORT=1 ;;
        f)
            REPO_TO_SCAN=${OPTARG} ;;
        r)
            ONLY_REPORT=1 ;;
        n)
            COV_PRJ_NAME=${OPTARG} ;;
        v)
            COV_PRJ_VER=${OPTARG} ;;
        d)
            COV_SNAPSHOT_ID=${OPTARG} ;;
        *)
            usage
            exit 1 ;;
    esac
done

if [ $((COV_SCAN_REPORT+ONLY_REPORT)) -eq 0 ]; then
    printf "\e[0;31m%-6s\e[m\n" "** ERROR: no scan option was selected. See usage for instructions\n"
    usage
    exit 1
fi


if [ "${COV_SCAN_REPORT}" -eq 1 ]; then
    export REPO_TO_SCAN COV_PRJ_NAME COV_PRJ_VER 

    # Git clone repo and run with coverity 

    #Generate config.yaml
    ./python3 generate_yaml.py --url "${COV_URL}" --project-name "${COV_PRJ_NAME}" --project-version "${COV_PRJ_VER}" --snapshot-id "${COV_SNAPSHOT_ID}" 
    
    # Generate report
    /opt/cov-reports-2024.3.1/bin/cov-generate-cvss-report config.yaml --user ${COV_USER} --password env:COVERITY_PASSPHRASE --report --output /output/ESG_${COV_PRJ_NAME}_coverity.pdf 

    SCAN_EXIT_CODE=$?
fi

if [ "${ONLY_REPORT}" -eq 1 ]; then
    
    if [ -e config.yaml  ]
      then
       rm -rf config.yaml
       echo "config.yaml deleted"
    fi

    echo "Cov project: ${COV_PRJ_NAME}"
    echo "Cov URL: ${COV_URL}"
    echo "Cov_version : ${COV_PRJ_VER}"
    echo "Cov Snapshot ID: ${COV_SNAPSHOT_ID}"
    echo "Coverity password ${COVERITY_PASSPHRASE}"

    
    #Generate config.yaml
    python3 generate_yaml.py --url "${COV_URL}" --project-name "${COV_PRJ_NAME}" --project-version "${COV_PRJ_VER}" --snapshot-id "${COV_SNAPSHOT_ID}" 

    curl ${COV_URL}
    
    # Generate report
   # /opt/cov-reports-2024.3.1/bin/cov-generate-cvss-report config.yaml --user ${COV_USER} --password env:COVERITY_PASSPHRASE --report --output /output/ESG_${COV_PRJ_NAME}_coverity.pdf 
    cov-generate-cvss-report config.yaml --user ${COV_USER} --password env:COVERITY_PASSPHRASE --report --output /output/ESG_${COV_PRJ_NAME}_coverity.pdf 
    
   
    
    SCAN_EXIT_CODE=$?
fi

exit "${SCAN_EXIT_CODE}"
